---
title: <span class="badge builder"></span> OptionsWithTooltip
---
# <span class="badge builder"></span> OptionsWithTooltip

## Constructor

```python
OptionsWithTooltip()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.OptionsWithTooltip
```

### <span class="badge object-method"></span> tooltip

```python
def tooltip(tooltip: cogbuilder.Builder[common.VizTooltipOptions]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [OptionsWithTooltip](./object-OptionsWithTooltip.md)
